%define subrel 2 

Summary:       An interactive computing environment for Python 
Name:          ipython
Version:       2.3.0
Release:       %mkrel 2
Source0:       http://pypi.python.org/packages/source/i/ipython/%{name}-%{version}.tar.gz
Patch0:        ipython-2.3.0-CVE-2015-4707.patch
Patch1:        ipython-2.3.0-mga16373.patch
License:       BSD
Group:         Development/Python
Url:           http://ipython.org
BuildArch:     noarch
Requires:      python-pexpect >= 2.2
Requires:      python-mglob
Requires:      python-simplegeneric
Recommends:      python-mpi4py
Recommends:      wxPython, python-qt4, pyside >= 1.0.3
Recommends:      python-pygments 
Recommends:      python-pyzmq >= 2.1.11
#notebook requires tornado and jinja2
Recommends:      python-tornado >= 3.1 
Recommends:      python-jinja2
Recommends:      python-matplotlib
BuildRequires: python-devel
BuildRequires: python-simplegeneric
BuildRequires: python-setuptools
BuildRequires: python-pygments
BuildRequires: python-sphinx 
BuildRequires: python-jinja2
BuildRequires: python-pyzmq >= 2.1.11
BuildRequires: python-pexpect >= 2.2
BuildRequires: python-tornado >= 3.1 
BuildRequires: python-matplotlib
BuildRequires: python-numpydoc
# ovitters: pkgconfig(gobject-introspection-1.0) includes script to determine typelib() auto buildrequires
BuildRequires: pkgconfig(gobject-introspection-1.0)

%package -n python3-ipython
Group:         Development/Python
Summary:       An enhanced interactive Python shell
BuildRequires: python3-devel
BuildRequires: python3-setuptools
BuildRequires: python3-simplegeneric
BuildRequires: python3-pygments
BuildRequires: python3-sphinx 
BuildRequires: python3-jinja2
BuildRequires: python3-pexpect
BuildRequires: python3-pyzmq
BuildRequires: python3-tornado 
Requires:      python3-pexpect
Requires:      python3-mglob
Requires:      python3-simplegeneric
Recommends:      python3-pygments
Recommends:      python3-sip
Recommends:      python3-qt4
Recommends:      python3-mpi4py
Recommends:      python3-tornado 
Recommends:      python3-jinja2
Recommends:      python3-matplotlib
Recommends:      python3-pyzmq

%description
The goal of IPython is to create a comprehensive environment for
interactive and exploratory computing. To support this goal, IPython
has two main components:

* An enhanced interactive Python shell.
* An architecture for interactive parallel computing.

The enhanced interactive Python shell has the following main features:

* Comprehensive object introspection.
* Input history, persistent across sessions.
* Caching of output results during a session with automatically
  generated references.
* Readline based name completion.
* Extensible system of 'magic' commands for controlling the
  environment and performing many tasks related either to IPython or
  the operating system.
* Configuration system with easy switching between different setups
  (simpler than changing $PYTHONSTARTUP environment variables every
  time).
* Session logging and reloading.
* Extensible syntax processing for special purpose situations.
* Access to the system shell with user-extensible alias system.
* Easily embeddable in other Python programs and wxPython GUIs.
* Integrated access to the pdb debugger and the Python profiler.

The parallel computing architecture has the following main features:

* Quickly parallelize Python code from an interactive Python/IPython
  session.
* A flexible and dynamic process model that be deployed on anything
  from multicore workstations to supercomputers.
* An architecture that supports many different styles of parallelism,
  from message passing to task farming.
* Both blocking and fully asynchronous interfaces.
* High level APIs that enable many things to be parallelized in a few
  lines of code.
* Share live parallel jobs with other users securely.
* Dynamically load balanced task farming system.  
* Robust error handling in parallel code.

%description -n python3-ipython
IPython provides a replacement for the interactive Python interpreter with
extra functionality.

Main features:
 * Comprehensive object introspection.
 * Input history, persistent across sessions.
 * Caching of output results during a session with automatically generated\
   references.
 * Readline based name completion.
 * Extensible system of 'magic' commands for controlling the environment and
   performing many tasks related either to IPython or the operating system.
 * Configuration system with easy switching between different setups (simpler
   than changing $PYTHONSTARTUP environment variables every time).
 * Session logging and reloading.
 * Extensible syntax processing for special purpose situations.
 * Access to the system shell with user-extensible alias system.
 * Easily embeddable in other Python programs.
 * Integrated access to the pdb debugger and the Python profiler.

%package doc
Summary:       An Enhanced Interactive Python Shell documentation
Group:         Development/Python

%description doc
IPython provides a replacement for the interactive python (Python)
interpreter with extra functionality.

This package contains comprehensive documentation for IPython in
html format, as well as examples of usage.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
# delete bundling libs
pushd IPython/external

# use decorators of numpy
rm decorators/_decorators.py

# other packages exist in Mageia
rm simplegeneric/_simplegeneric.py
rm pexpect/_pexpect.py

popd

# Get rid of library shebangs
find . -type f -name "*.py" -exec sed -i '/#!\/usr\/bin\/env/d' {} \;

cp -a . %{py3dir}

%build
pushd %{py3dir}
%{__python3} setup.py build
popd

%{__python} setup.py build

%install
pushd %{py3dir}
%{__python3} setup.py install -O1 --skip-build --root %{buildroot} 
rm %{buildroot}%{_bindir}/ipython
rm %{buildroot}%{_bindir}/ipcluster
rm %{buildroot}%{_bindir}/ipcontroller
rm %{buildroot}%{_bindir}/ipengine
rm %{buildroot}%{_bindir}/iptest

popd

%{__python} setup.py install -O1 --skip-build --root %{buildroot}

chmod 644 %{buildroot}%{_mandir}/man1/*.1*
find %{buildroot} -name .buildinfo -exec rm -f {} \;
find %{buildroot} -name .git_commit_info.ini -exec rm -rf {} \;

# make docs
pushd docs
PYTHONPATH=$PYTHONPATH:%{buildroot}%{python_sitelib} make html
rm build/html/.buildinfo
popd

%files
%{_bindir}/ipython
%{_bindir}/ipcluster
%{_bindir}/ipcontroller
%{_bindir}/ipengine
%{_bindir}/iptest
%{_bindir}/ipython2
%{_bindir}/ipcluster2
%{_bindir}/ipcontroller2
%{_bindir}/ipengine2
%{_bindir}/iptest2

%{python_sitelib}/*

%files doc
%doc examples docs/build/html
%{_mandir}/man1/*

%files -n python3-ipython 
%{_bindir}/ipython3
%{_bindir}/ipcluster3
%{_bindir}/ipcontroller3
%{_bindir}/ipengine3
%{_bindir}/iptest3

%{python3_sitelib}/*



%changelog
* Tue Jul 14 2015 philippem <philippem> 2.3.0-2.2.mga5
+ Revision: 853759
- fix mga#16373 with upstream patch
- fix  CVE-2015-4707 mga#16183

* Wed Oct 15 2014 umeabot <umeabot> 2.3.0-2.mga5
+ Revision: 742139
- Second Mageia 5 Mass Rebuild

* Wed Oct 08 2014 luigiwalser <luigiwalser> 2.3.0-1.mga5
+ Revision: 737598
- 2.3.0

* Sat Sep 27 2014 tv <tv> 2.2.0-4.mga5
+ Revision: 726524
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.2.0-3.mga5
+ Revision: 680560
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

  + ovitters <ovitters>
    - add gobject-introspection BR for typelib auto BR

* Sun Sep 14 2014 joequant <joequant> 2.2.0-2.mga5
+ Revision: 675217
- rebuild for dependencies

* Fri Aug 08 2014 philippem <philippem> 2.2.0-1.mga5
+ Revision: 661160
- update to 2.2.0

* Sat May 31 2014 pterjan <pterjan> 2.1.0-3.mga5
+ Revision: 629679
- Rebuild for new Python

* Sat May 31 2014 pterjan <pterjan> 2.1.0-2.mga5
+ Revision: 628266
- Rebuild for new Python

* Fri May 23 2014 luigiwalser <luigiwalser> 2.1.0-1.mga5
+ Revision: 625225
- 2.1.0

* Thu Apr 10 2014 philippem <philippem> 2.0.0-2.mga5
+ Revision: 613307
- add missing suggests for python3

* Thu Apr 03 2014 philippem <philippem> 2.0.0-1.mga5
+ Revision: 611437
- update to 2.0.0

* Sun Mar 16 2014 philippem <philippem> 1.2.1-2.mga5
+ Revision: 604190
- add Python3

* Wed Feb 26 2014 luigiwalser <luigiwalser> 1.2.1-1.mga5
+ Revision: 597331
- 1.2.1

* Fri Feb 14 2014 luigiwalser <luigiwalser> 1.2.0-1.mga5
+ Revision: 590999
- 1.2.0

* Tue Oct 22 2013 umeabot <umeabot> 1.1.0-3.mga4
+ Revision: 544806
- Mageia 4 Mass Rebuild

* Fri Oct 18 2013 malo <malo> 1.1.0-2.mga4
+ Revision: 519210
- fix suggests to jinja2 and tornado (patch by Daniel Napora)

* Tue Oct 15 2013 luigiwalser <luigiwalser> 1.1.0-1.mga4
+ Revision: 500286
- 1.1.0

* Mon Oct 14 2013 pterjan <pterjan> 1.0.0-2.mga4
+ Revision: 497820
- Rebuild to add different pythonegg provides for python 2 and 3

* Tue Aug 20 2013 luigiwalser <luigiwalser> 1.0.0-1.mga4
+ Revision: 468289
- 1.0.0

* Sun Aug 04 2013 joequant <joequant> 0.13.2-2.mga4
+ Revision: 463116
- redo spec
- suggest torando for ipython notebook

* Sun Apr 07 2013 luigiwalser <luigiwalser> 0.13.2-1.mga3
+ Revision: 408637
- 0.13.2

* Sat Jan 12 2013 umeabot <umeabot> 0.13.1-2.mga3
+ Revision: 354491
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 03 2013 luigiwalser <luigiwalser> 0.13.1-1.mga3
+ Revision: 338399
- 0.13.1

* Mon Oct 22 2012 dams <dams> 0.13-1.mga3
+ Revision: 309263
- new version 0.13

* Tue Sep 20 2011 lebedov <lebedov> 0.11-2.mga2
+ Revision: 146101
- Update to 0.11.

* Thu Apr 21 2011 ahmad <ahmad> 0.10.2-1.mga1
+ Revision: 89370
- Update to 0.10.2
- Drop patch0, redundant now that man pages get compressed properl without it
- Replace the deprecated %%py_requires macro with BR python-devel
- Use the upstream %%{python_sitelib} macro
- Don't copy REAME.txt manually, %%doc it instead

* Sun Mar 06 2011 saispo <saispo> 0.10.1-1.mga1
+ Revision: 65239
- imported package ipython

